@@ -1,6 +1,6 @@
 mod structs;
 mod traits;
-use structs::cash::Cash;
+pub use structs::cash::Cash;
 use traits::create::Procedures;
 use traits::calculate::Operations;
 
